##  Accessing and Using the Templates
In the left navigation sidebar, under the Templates section, select BTP Reference Architecture to view the collection of SAP BTP reference architecture templates.
Selecting a template opens it in view mode. Each diagram includes a description that provides context and explains its purpose.
To edit, click Use Template in the top-right corner. This action clones the template and opens it in edit mode, allowing you to customize and save it as a new diagram. Note that the original template remains unchanged.
In the edit mode, you can connect the shapes to relevant fact sheets to ensure the diagram is accurate and up-to-date with your organization's real architecture data. To know how to connect shapes to fact sheets, see [Linking and Unlinking Fact Sheets to Shapes](https://help.sap.com/docs/leanix/ea/free-draw?locale=en-US&state=PRODUCTION&version=CLOUD#loio275a369c7a4410148ff4e12bcf658e03__linking_and_unlinking_fact_sheets_to_shapes_in_diagrams).
![Using SAP BTP Reference Architecture Templates](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27480e047a441014bfb396e1f72d920c_LowRes.gif)
Using SAP BTP Reference Architecture Templates
